using MusiLib.Model;
using System.Diagnostics;

namespace MusiLib.Views;


public partial class Favoris : ContentPage, IAllowClick
{

    public Manager MyManager => (App.Current as App).MyManager;

    private List<Partition> partitionsInitiales;
    private List<Partition> partitionsFiltrees;

    public Favoris()
	{
		InitializeComponent();
        partitionsInitiales = MyManager.favoris.ToList();
        partitionsFiltrees = new List<Partition>(partitionsInitiales);
        chargerFavoris();
    }


    private void GoToAccueilByLogoButton(object sender, EventArgs e)
    {
        if (!IAllowClick.AllowTap) return;
        else IAllowClick.AllowTap = false;

        Navigation.PopAsync();

        IAllowClick.ResumeTap();
    }


    private void GoToPartitionButton(object sender, EventArgs e)
    {
        if (!IAllowClick.AllowTap) return; 
        else IAllowClick.AllowTap = false;

        var button = (ImageButton)sender;
        var idAutomation = button.AutomationId;

        if (int.TryParse(idAutomation, out int id))
        {
            Navigation.PushAsync(new PartitionView(id));
        }

        IAllowClick.ResumeTap();
    }


    private void chargerFavoris()
    {
        var imageButtonsToRemove = grille.Children.OfType<ImageButton>().Where(btn => !string.IsNullOrEmpty(btn.AutomationId)).ToList();
        foreach (var button in imageButtonsToRemove)
        {
            grille.Children.Remove(button);
        }

        int imagesParLigne = 3;
        int indice = 0;

        foreach (Partition favoris in partitionsFiltrees) 
        {
            int indicePartition = MyManager.partitions.IndexOf(favoris);

            ImageButton imageButton = new ImageButton
            {
                Source = favoris.Image[0],
                WidthRequest = 175,
                HeightRequest = 175,
                AutomationId = indicePartition.ToString(),
            };

            imageButton.Clicked += GoToPartitionButton;

            int ligne = 1 + (indice / imagesParLigne);
            int colonne = indice % imagesParLigne;

            imageButton.Margin = GetImageButtonMargin(colonne);

            Grid.SetRow(imageButton, ligne);
            Grid.SetColumn(imageButton, colonne);
            grille.Children.Add(imageButton);

            Console.WriteLine(favoris.Nom);

            indice++;
        }
    }

    private Thickness GetImageButtonMargin(int colonne)
    {
        if (colonne == 0)
        {
            return new Thickness(30, 0, 0, 0);
        }
        else if (colonne == 1)
        {
            return new Thickness(90, 0, 0, 0);
        }
        else
        {
            return new Thickness(150, 0, 0, 0);
        }
    }

    private void SearchBar_TextChanged(object sender, TextChangedEventArgs e)
    {
        string texteRecherche = e.NewTextValue;

        partitionsFiltrees.Clear();

        foreach (Partition partition in partitionsInitiales)
        {
            if (partition.Nom.ToLower().Contains(texteRecherche.ToLower()))
            {
                partitionsFiltrees.Add(partition);
            }
        }

        chargerFavoris();
    }

    protected override void OnAppearing()
    {
        base.OnAppearing();
        partitionsInitiales = MyManager.favoris.ToList();
        partitionsFiltrees = new List<Partition>(partitionsInitiales);
        chargerFavoris();
    }

}