using Microsoft.Maui.Controls.PlatformConfiguration;
using MusiLib.Model;
using System.Collections.Concurrent;
using System.Diagnostics;

namespace MusiLib.Views;


public partial class PartitionView : ContentPage
{

    public Manager MyManager => (App.Current as App).MyManager;

    public int IdTab { get; set; }


    public PartitionView()
	{
		InitializeComponent();
        BindingContext = MyManager;
    }

    public PartitionView(int id)
    {
        InitializeComponent();
        IdTab = id;
        Part.BindingContext = MyManager.partitions[IdTab];
        Part2.BindingContext = MyManager;

        InitializeButton();
    }

    private void Play_Music(object sender, EventArgs e)
    {
        Button button = (Button)sender;
        if (!IPlayMusic.isMusicBeginning)
        {
            IPlayMusic.beginMusic(MyManager.partitions[IdTab].Son);
            button.Text = "Pause";
        }
        else if(!IPlayMusic.isMusicPlaying)
        {
            IPlayMusic.playMusic();
            button.Text = "Pause";
        }
        else
        {
            IPlayMusic.pauseMusic();
            button.Text = "Jouer";
        }
    }

    private void Stop_Music(object sender, EventArgs e)
    {
        IPlayMusic.stopMusic();
        Button button = (Button)FindByName("play_music_button");
        button.Text = "Jouer";
    }

    protected override bool OnBackButtonPressed()
    {
        IPlayMusic.stopMusic();
        return base.OnBackButtonPressed();
    }

    protected override void OnDisappearing()
    {
        base.OnDisappearing();
        IPlayMusic.stopMusic();
    }

    protected override void OnAppearing()
    {
        base.OnAppearing();
        Shell.Current.Navigating += Shell_Navigating;
    }

    private void Shell_Navigating(object sender, ShellNavigatingEventArgs e)
    {
        if (e.Source == ShellNavigationSource.ShellItemChanged)
        {
            IPlayMusic.stopMusic();
        }
    }

    private void InitializeButton()
    {
        if (MyManager.favoris.Contains(MyManager.partitions[IdTab]))
        {
            favoriButton.Source = "etoile.png";
        }
        else
        {
            favoriButton.Source = "etoile_vide.png";
        }
    }

    private void AddFavoriButton(object sender, EventArgs e)
    {
        ImageButton button = (ImageButton)sender;

        if (!MyManager.favoris.Contains(MyManager.partitions[IdTab]))
        {
            MyManager.favoris.Add(MyManager.partitions[IdTab]);
            MyManager.sauvegardeFavori(MyManager.partitions[IdTab]);
            button.Source = "etoile.png";
        }
       else
        {
            MyManager.favoris.Remove(MyManager.partitions[IdTab]);
            button.Source = "etoile_vide.png";
        }
    }
}
